"""这个函数去一个位置参数，为the_list,可以是任何列表，指定的列表中的每个数据项会递归地
输出到屏幕上，个数据项占一行"""
def print1991(the_list):
	for each_item in the_list:
		if isinstance(each_item,list):
			print_lol(each_item)
		else:
			print(each_item)



from distutils.core import setup

setup(
         name         = 'print1991',
         version      = '1.0.0',
         py_modules   = ['print1991'],
         author       = 'hfpython',
         author_email = 'hfpython@headfirstlabs.com',
         url          = 'http://www.headfirstlabs.com',
         description  = 'A simple printer of nested lists',

 )
